![OMAS version](https://img.shields.io/github/tag-date/gafusion/omas.svg?label=OMAS&color=blue)
![IMAS version](https://img.shields.io/badge/IMAS-3.38.1-yellow)

![GitHub repo size](https://img.shields.io/github/repo-size/gafusion/omas.svg?color=blue)

# **OMAS** (**O**rdered **M**ultidimensional **A**rray **S**tructure)

OMAS is a Python library designed to simplify the interface of third-party codes with the [ITER](http://iter.org) Integrated Modeling and Analysis Suite ([IMAS](https://confluence.iter.org/display/IMP)).

* It provides a **convenient Python API**

* capable of storing data with **different file/database formats**

* in a form that is **always compatible with the IMAS data model**

Mapping the physics codes I/O to the IMAS data model is done in third party Python codes such as the [OMFIT framework](https://omfit.io).

For more info, visit: https://gafusion.github.io/omas
